
From: Jim Hague <jim.hague@acm.org>

Handle 24bit on big-endian by leaving the hardware in RGB and using the
colour offset to reverse red/blue.  Leaving the hardware in RGB means that
fbi displays images correctly (abeit fortuitously) and the console is
correct, thanks to a recent patch to the console code correcting an endian
bug in fbcon_putc().

Signed-off-by: Jim Hague <jim.hague@acm.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/video/pm2fb.c |   16 +++++++++++-----
 1 files changed, 11 insertions(+), 5 deletions(-)

diff -puN drivers/video/pm2fb.c~pm2fb-fix-fbi-image-display-on-24-bit-depth-big-endian drivers/video/pm2fb.c
--- 25/drivers/video/pm2fb.c~pm2fb-fix-fbi-image-display-on-24-bit-depth-big-endian	Fri Dec 10 15:08:09 2004
+++ 25-akpm/drivers/video/pm2fb.c	Fri Dec 10 15:08:09 2004
@@ -646,12 +646,22 @@ static int pm2fb_check_var(struct fb_var
 	case 32:
 		var->transp.offset = 24;
 		var->transp.length = 8;
-	case 24:
 		var->red.offset	  = 16;
 		var->green.offset = 8;
 		var->blue.offset  = 0;
 		var->red.length = var->green.length = var->blue.length = 8;
 		break;
+	case 24:
+#ifdef __BIG_ENDIAN
+		var->red.offset   = 0;
+		var->blue.offset  = 16;
+#else
+		var->red.offset   = 16;
+		var->blue.offset  = 0;
+#endif
+		var->green.offset = 8;
+		var->red.length = var->green.length = var->blue.length = 8;
+		break;
 	}
 	var->height = var->width = -1;
   
@@ -789,10 +799,6 @@ static int pm2fb_set_par(struct fb_info 
 	case 24:
 		pm2_WR(par, PM2R_FB_READ_PIXEL, 4);
 		clrmode |= PM2F_RD_TRUECOLOR | PM2F_RD_PIXELFORMAT_RGB888;
-#ifdef __BIG_ENDIAN
-		/* Use BGR not RGB */
-		clrmode &= ~PM2F_RD_COLOR_MODE_RGB;
-#endif
 		txtmap = PM2F_TEXTEL_SIZE_24;
 		pixsize = 4;
 		clrformat = 0x20;
_
